==> haskell-here-1.2.13-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-HUUnB3YxQblGYou4J8ye03
key: here-1.2.13-HUUnB3YxQblGYou4J8ye03
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: a7bfcdbb7f2411d1857b23b3191d3ece
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.6.5/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/here-1.2.13
hs-libraries: HShere-1.2.13-HUUnB3YxQblGYou4J8ye03
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-BYEwMiPdjrnJwT3Qu9g1eB
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.13-88-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-3WHSxSnHUwVK1qqeX7uDcW
key: here-1.2.13-3WHSxSnHUwVK1qqeX7uDcW
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: 1604781483cb051f27ab33c056e1db9e
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.6.5/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/here-1.2.13
hs-libraries: HShere-1.2.13-3WHSxSnHUwVK1qqeX7uDcW
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-L1oODBLrG4O2KB6sCPs5NT
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
